@@ -7,4 +7,6 @@ from .wacz_enricher import WaczArchiverEnricher
 from .whisper_enricher import WhisperEnricher
 from .pdq_hash_enricher import PdqHashEnricher
 from .metadata_enricher import MetadataEnricher
-from .meta_enricher import MetaEnricher
\ No newline at end of file
+from .meta_enricher import MetaEnricher
+from .ssl_enricher import SSLEnricher
+from .timestamping_enricher import TimestampingEnricher
\ No newline at end of file
